@@ -2,6 +2,7 @@ from cloudpy_struct import DirStruct
 import sh
 import os
 import sys
+import pkg_resources
 
 
 class Agent(object):
@@ -20,10 +21,11 @@ class Agent(object):
                 line = line.strip()
                 if line and not line.startswith("#"):
                     items = line.split()
-                    if len(items) == 1:
-                        self.mods.append(items[0])
-                    else:
-                        self.mods.append("==".join(items))
+                    if items[0] in pkg_resources.working_set:
+                        if len(items) == 1:
+                            self.mods.append(items[0])
+                        else:
+                            self.mods.append("==".join(items))
 
     def read_conf(self):
         with open(self.dir.CONF_FILE, "r") as f:
